import 'dart:convert' as convert;

class Rules {
  const Rules(this.value);
  final List<Rule> value;
  factory Rules.fromParsedYaml(dynamic parsedYaml) {
    final encoded = convert.jsonEncode(parsedYaml['rules']);
    final rulesMap = convert.jsonDecode(encoded) as Map<String, dynamic>;
    final ruleNames = rulesMap.keys.toList();

    final result = <Rule>[];
    for (final name in ruleNames) {
      final rule = rulesMap[name];

      final checkFileRegExp = RegExp(rule['check_file_reg_exp']);
      final notArrowImportRegExps =
          (rule['not_arrow_import_reg_exps'] as List<dynamic>)
              .map((e) => RegExp(e.toString()))
              .toList();

      result.add(
        Rule(
          name: name,
          checkFileRegExp: checkFileRegExp,
          notArrowImportRegExps: notArrowImportRegExps,
        ),
      );
    }
    return Rules(result);
  }
}

class Rule {
  const Rule({
    required this.name,
    required this.checkFileRegExp,
    required this.notArrowImportRegExps,
  });

  final String name;
  final RegExp checkFileRegExp;
  final List<RegExp> notArrowImportRegExps;
}
